Module beamlit.models.store_function_labels
===========================================

Classes
-------

`StoreFunctionLabels()`
:   Store function labels
    
    Method generated by attrs for class StoreFunctionLabels.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :